@@ -25,6 +25,7 @@ expt_id_ok: 'prediction with 2010 volcano' 'volcIn2010'
 expt_id_ok: 'pre-industrial control' 'piControl'
 expt_id_ok: 'historical' 'historical'
 expt_id_ok: 'historical extension' 'historicalExt'
+expt_id_ok: 'other historical forcing' 'historicalMisc'
 expt_id_ok: 'mid-Holocene' 'midHolocene'
 expt_id_ok: 'last glacial maximum' 'lgm'
 expt_id_ok: 'last millennium' 'past1000'
@@ -531,6 +532,12 @@ def create_table(table_file, dims_file,minmax={}):
                 minmaxpassed={}
             else:
                 minmaxpassed=minmax
+                for v in ["sltovovrt","sltovgyre"]:
+                    try:
+                        del(minmaxpassed[v])
+                    except:
+                        pass
+                
             print >> fo, process_template(var_tmpl,cnms,sp,{'CMOR variable name':['?','0','0.0']},minmax=minmaxpassed,iadd=iadd)
     print 'Created tables:',tables.keys()
                 
